ErrorActionPlan class final

Explicit actions selected for a classified error.

Constructors

ErrorActionPlan({required ErrorReportingDirective reporting, required ErrorPresentationDirective presentation, required ErrorRecoveryDirective recovery})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
presentation ErrorPresentationDirective
Presentation action.
final
recovery ErrorRecoveryDirective
Recovery action.
final
reporting ErrorReportingDirective
Reporting action.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited