ErrorPipelineFailure class final

Failure produced by the error-management pipeline itself.

Constructors

ErrorPipelineFailure({required ErrorPipelineStage stage, required Object error, required StackTrace stackTrace, String? incidentId, String? component})
const

Properties

component String?
Runtime component that failed, when known.
final
error Object
Pipeline error.
final
hashCode int
The hash code for this object.
no setterinherited
incidentId String?
Incident being processed, when one had already been allocated.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
Pipeline stack trace.
final
stage ErrorPipelineStage
Failed stage.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited