StrictErrorSanitizer class final

Sanitizer that masks common secret-bearing fields and bounds raw context.

Implemented types

Constructors

StrictErrorSanitizer({ErrorSanitizationLimits limits = const ErrorSanitizationLimits()})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
limits ErrorSanitizationLimits
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sanitize(ErrorIncident incident) ErrorReport
Removes or masks sensitive values and returns a report.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited